#!/usr/bin/env python2
#
#  Valosoitin - Audio player for EFL
#
#  Copyright 2012-2013 Kai Huuhko <kai.huuhko@gmail.com>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#

import elementary as elm

class PlayControls(elm.Box):
    def __init__(self, parent):
        window = parent.window
        elm.Box.__init__(self, window)

        prev = elm.Button(window)
        prev_ic = elm.Icon(window)
        prev_ic.standard_set("media-skip-backward")
        prev.content_set(prev_ic)
        prev.callback_clicked_add(parent.nx, prev=True)
        prev.size_hint_min_set(30, 30)
        prev.size_hint_weight_set(1.0, 1.0)
        prev.size_hint_align_set(-1.0, -1.0)
        prev.show()

        self.play = play = elm.Button(window)
        play_ic = elm.Icon(window)
        play_ic.standard_set("media-playback-start")
        play.content_set(play_ic)
        play.callback_clicked_add(parent.play_pause)
        play.size_hint_min_set(30, 30)
        play.size_hint_weight_set(1.0, 1.0)
        play.size_hint_align_set(-1.0, -1.0)
        play.show()

        nx = elm.Button(window)
        nx_ic = elm.Icon(window)
        nx_ic.standard_set("media-skip-forward")
        nx.content_set(nx_ic)
        nx.callback_clicked_add(parent.nx)
        nx.size_hint_min_set(30, 30)
        nx.size_hint_weight_set(1.0, 1.0)
        nx.size_hint_align_set(-1.0, -1.0)
        nx.show()

        self.horizontal_set(True)
        self.pack_end(prev)
        self.pack_end(play)
        self.pack_end(nx)
        self.size_hint_weight_set(1.0, 1.0)
        self.size_hint_align_set(-1.0, -1.0)
        self.show()

class VolumeControls(elm.Frame):
    def __init__(self, parent):
        window = parent.window
        elm.Frame.__init__(self, window)

        self.mute = mute = elm.Check(window)
        mute.text_set("Mute")
        mute.callback_changed_add(parent.mute)
        mute.show()

        self.volume = volume = elm.Slider(window)
        volume.min_max_set(0.0, 100.0)
        volume.indicator_format_set("%.0f%")
        volume.callback_changed_add(parent.change_volume)
        volume.size_hint_weight_set(1.0, 0.0)
        volume.size_hint_align_set(-1.0, 0.0)
        volume.show()

        self.size_hint_align_set(-1.0, 0.0)
        volumebox = elm.Box(window)
        volumebox.horizontal_set(True)
        volumebox.size_hint_weight_set(1.0, 0.0)
        volumebox.size_hint_align_set(-1.0, 0.0)
        volumebox.pack_end(mute)
        volumebox.pack_end(volume)
        volumebox.show()
        self.content_set(volumebox)
        self.text = "Volume control"
        self.show()

class PlayModes(elm.Frame):
    def __init__(self, parent):
        window = parent.window
        elm.Frame.__init__(self, window)

        self.single = single = elm.Check(window)
        single.callback_changed_add(parent.set_play_mode)
        single.text_set("Single")
        try:
            single.state_set(conf.getboolean("Settings", "single"))
        except:
            pass
        single.show()

        self.random = random = elm.Check(window)
        random.callback_changed_add(parent.set_random_mode)
        random.text_set("Random")
        try:
            random.state_set(conf.getboolean("Settings", "random"))
        except:
            pass
        random.show()

        self.repeat = repeat = elm.Check(window)
        repeat.callback_changed_add(parent.set_play_mode)
        repeat.text_set("Repeat")
        try:
            repeat.state_set(conf.getboolean("Settings", "repeat"))
        except:
            pass
        repeat.show()

        playmodes = elm.Box(window)
        playmodes.horizontal_set(True)
        playmodes.pack_end(single)
        playmodes.pack_end(random)
        playmodes.pack_end(repeat)
        playmodes.show()
        self.content_set(playmodes)
        self.text = "Play modes"
        self.show()

class SeekControls(elm.Box):
    def __init__(self, parent):
        window = parent.window
        elm.Box.__init__(self, window)

        self.seek = seek = elm.Slider(window)
        seek.callback_slider_drag_start_add(parent.seekstart)
        seek.callback_slider_drag_stop_add(parent.seektime)
        seek.size_hint_weight_set(1.0, 0.0)
        seek.size_hint_align_set(-1.0, 0.0)
        seek.show()

        self.seektime = seektime = elm.Label(window)
        seektime.text_set("0:00:00 / 0:00:00")
        seektime.show()

        self.horizontal_set(True)
        self.size_hint_weight_set(1.0, 0.0)
        self.size_hint_align_set(-1.0, 0.0)
        self.pack_end(seek)
        self.pack_end(seektime)
        self.show()
