#!/usr/bin/env python2
#
#  Valosoitin - Audio player for EFL
#
#  Copyright 2012-2013 Kai Huuhko <kai.huuhko@gmail.com>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#

import os
import cgi
import urllib

from evas import EVAS_ASPECT_CONTROL_VERTICAL
import elementary as elm

class PlayList(elm.Genlist):
    def __init__(self, parent):
        window = parent.window
        elm.Genlist.__init__(self, window)

        self.multi_select_set(False)
        self.reorder_mode_set(True)
        self.callback_selected_add(parent.item_selected)
        self.callback_clicked_double_add(parent.play_selected)
        self.callback_moved_add(self.item_moved, parent)
        self.size_hint_weight_set(1.0, 1.0)
        self.size_hint_align_set(-1.0, -1.0)
        self.show()

    def item_moved(self, gl, item, parent):
        i = parent.playlistindex
        o = i.index(item.data[1].filename)
        if item.prev:
            p = i.index(item.prev.data[1].filename)
            if o > p:
                p = p+1
            i.insert(p, i.pop(o))
        else:
            i.insert(0, i.pop(o))

class PlayListControls(elm.Box):
    def __init__(self, parent):
        window = parent.window
        elm.Box.__init__(self, window)

        addFile = elm.Button(window)
        addFile.text_set("Add file")
        addFile.callback_clicked_add(self.select_files, parent, folder=False)
        addFile.show()

        addDir = elm.Button(window)
        addDir.text_set("Add directory")
        addDir.callback_clicked_add(self.select_files, parent, folder=True)
        addDir.show()

        rm = elm.Button(window)
        rm.text_set("Remove")
        rm.callback_clicked_add(self.remove_selected_cb, parent)
        rm.show()

        cl = elm.Button(window)
        cl.text_set("Clear")
        cl.callback_clicked_add(self.clear_playlist, parent)
        cl.show()

        self.plinfo = plinfo = elm.Label(window)
        plinfo.size_hint_weight_set(1.0, 0.0)
        plinfo.size_hint_align_set(1.0, 0.5)
        plinfo.text_set("")
        plinfo.show()

        self.horizontal_set(True)
        self.size_hint_weight_set(1.0, 0.0)
        self.size_hint_align_set(-1.0, 0.0)
        self.pack_end(addFile)
        self.pack_end(addDir)
        self.pack_end(rm)
        self.pack_end(cl)
        self.pack_end(plinfo)
        self.show()

    def remove_selected_cb(self, btn, parent):
        if parent.playlist.multi_select_get():
            self.n.delete()
            del self.n
            btn.style = "default"
            parent.playlist.multi_select_set(False)
            self.remove_selected(parent)
        else:
            btn.style = "anchor"
            i = parent.playlist.selected_item
            if i:
                i.selected_set(False)
            parent.playlist.multi_select_set(True)
            l = elm.Label(parent.window)
            l.text = "Select the tracks you wish to remove and press Remove when done."
            n = self.n = elm.Notify(parent.window)
            n.orient = elm.ELM_NOTIFY_ORIENT_TOP
            n.content = l
            n.show()

    def remove_selected(self, parent):
        items = parent.playlist.selected_items_get()
        if not items:
            return
        for item in items:
            player, m = item.data_get()
            f = "file://"+m.filename
            item.delete()
            del parent.playlistitems[m.filename]
            parent.playlistindex.remove(m.filename)

    def select_files(self, btn, parent, folder=False):
        i = elm.InnerWindow(parent.window)
        b = elm.Box(parent.window)
        fs = elm.Fileselector(parent.window)
        fs.folder_only_set(folder)
        if folder:
            fs.callback_done_add(parent.add_dir)
        else:
            fs.callback_done_add(parent.add_file)
        fs.callback_done_add(lambda x, y: i.delete())

        b.size_hint_align_set(-1.0, -1.0)
        b.size_hint_weight_set(1.0, 1.0)
        fs.size_hint_align_set(-1.0, -1.0)
        fs.size_hint_weight_set(1.0, 1.0)

        b.pack_end(fs)
        i.content_set(b)
        fs.show()
        b.show()
        i.activate()

    def clear_playlist(self, btn, parent):
        parent.playlist.clear()
        parent.playlistitems.clear()
        del parent.playlistindex[:]

class PlayListItem(elm.GenlistItemClass):
    def text_get(self, genlist, part, info):
        player, m = info
        if not "mutagen" in str(type(m)):
            return os.path.basename(m)

        if m.get("artist"):
            artists = ", ".join(m.get("artist"))
        else:
            artists = "Unknown artist"
        if m.get("album"):
            albums = ", ".join(m.get("album"))
        else:
            albums = "Unknown album"
        if m.get("title"):
            titles = ", ".join(m.get("title"))
        else:
            titles = m.filename

        entry = cgi.escape(" - ".join((artists, albums, titles)))
        return entry

    def content_get(self, genlist, part, info):
        player, m = info
        if part == "elm.swallow.icon":
            if not "mutagen" in str(type(m)):
                filename = m
            else:
                filename = m.filename

            ic = elm.Icon(genlist)
            if player.file_get() == "file://"+urllib.quote(filename):
                ic.standard_set("media-playback-start")
            else:
                ic.standard_set("media-playback-pause")
            ic.size_hint_aspect_set(EVAS_ASPECT_CONTROL_VERTICAL, 1, 1)
            return ic
